@@ -417,7 +417,7 @@ void KGrSLDialog::slGame()
         display->setMaximum (1);
     }
 
-    KConfigGroup gameGroup (KSharedConfig::openConfig(), "KDEGame");
+    KConfigGroup gameGroup (KSharedConfig::openConfig(), QStringLiteral("KDEGame"));
     int lev = 1;
 
     // Set a default level number for the selected game.
@@ -661,8 +661,7 @@ void KGrThumbNail::paintEvent (QPaintEvent * /* event (unused) */)
     QColor poleColor =       QColor ("#a0a0a0"); // Steely grey.
     QColor heroColor =       QColor ("#00ff00"); // Green.
     QColor enemyColor =      QColor ("#0080ff"); // Bright blue.
-    QColor gold;
-    gold.setNamedColor (QStringLiteral("gold"));		 // Gold.
+    QColor gold =            QColor::fromString(QStringLiteral("gold")); // Gold.
 
     pen.setColor (backgroundColor);
     p.setPen (pen);
